=== modified file 'drizzled/functions/Makefile.am'
--- drizzled/functions/Makefile.am	2008-10-09 20:33:45 +0000
+++ drizzled/functions/Makefile.am	2008-10-09 21:04:57 +0000
@@ -18,6 +18,7 @@
 noinst_LTLIBRARIES = 	libfunctions.la
 
 libfunctions_la_SOURCES = connection_id.cc \
+			  decimal_typecast.cc \
 			  func.cc \
                           int.cc \
 			  num1.cc \
@@ -28,6 +29,7 @@
 			  unsigned.cc
 
 noinst_HEADERS = connection_id.h \
+		 decimal_typecast.h \
 		 func.h \
                  int.h \
 		 num1.h \

=== added file 'drizzled/functions/decimal_typecast.cc'
--- drizzled/functions/decimal_typecast.cc	1970-01-01 00:00:00 +0000
+++ drizzled/functions/decimal_typecast.cc	2008-10-09 21:04:57 +0000
@@ -0,0 +1,117 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include <drizzled/server_includes.h>
+#include CSTDINT_H
+#include <drizzled/functions/decimal_typecast.h>
+#include <drizzled/drizzled_error_messages.h>
+
+
+String *Item_decimal_typecast::val_str(String *str)
+{
+  my_decimal tmp_buf, *tmp= val_decimal(&tmp_buf);
+  if (null_value)
+    return NULL;
+  my_decimal2string(E_DEC_FATAL_ERROR, tmp, 0, 0, 0, str);
+  return str;
+}
+
+
+double Item_decimal_typecast::val_real()
+{
+  my_decimal tmp_buf, *tmp= val_decimal(&tmp_buf);
+  double res;
+  if (null_value)
+    return 0.0;
+  my_decimal2double(E_DEC_FATAL_ERROR, tmp, &res);
+  return res;
+}
+
+
+int64_t Item_decimal_typecast::val_int()
+{
+  my_decimal tmp_buf, *tmp= val_decimal(&tmp_buf);
+  int64_t res;
+  if (null_value)
+    return 0;
+  my_decimal2int(E_DEC_FATAL_ERROR, tmp, unsigned_flag, &res);
+  return res;
+}
+
+
+my_decimal *Item_decimal_typecast::val_decimal(my_decimal *dec)
+{
+  my_decimal tmp_buf, *tmp= args[0]->val_decimal(&tmp_buf);
+  bool sign;
+  uint32_t precision;
+
+  if ((null_value= args[0]->null_value))
+    return NULL;
+  my_decimal_round(E_DEC_FATAL_ERROR, tmp, decimals, false, dec);
+  sign= dec->sign();
+  if (unsigned_flag)
+  {
+    if (sign)
+    {
+      my_decimal_set_zero(dec);
+      goto err;
+    }
+  }
+  precision= my_decimal_length_to_precision(max_length,
+                                            decimals, unsigned_flag);
+  if (precision - decimals < (uint) my_decimal_intg(dec))
+  {
+    max_my_decimal(dec, precision, decimals);
+    dec->sign(sign);
+    goto err;
+  }
+  return dec;
+
+err:
+  push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
+                      ER_WARN_DATA_OUT_OF_RANGE,
+                      ER(ER_WARN_DATA_OUT_OF_RANGE),
+                      name, 1);
+  return dec;
+}
+
+
+void Item_decimal_typecast::print(String *str, enum_query_type query_type)
+{
+  char len_buf[20*3 + 1];
+  char *end;
+
+  uint32_t precision= my_decimal_length_to_precision(max_length, decimals,
+                                                 unsigned_flag);
+  str->append(STRING_WITH_LEN("cast("));
+  args[0]->print(str, query_type);
+  str->append(STRING_WITH_LEN(" as decimal("));
+
+  end=int10_to_str(precision, len_buf,10);
+  str->append(len_buf, (uint32_t) (end - len_buf));
+
+  str->append(',');
+
+  end=int10_to_str(decimals, len_buf,10);
+  str->append(len_buf, (uint32_t) (end - len_buf));
+
+  str->append(')');
+  str->append(')');
+}
+

=== added file 'drizzled/functions/decimal_typecast.h'
--- drizzled/functions/decimal_typecast.h	1970-01-01 00:00:00 +0000
+++ drizzled/functions/decimal_typecast.h	2008-10-09 21:04:57 +0000
@@ -0,0 +1,46 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_FUNCTIONS_DECIMAL_TYPECAST_H
+#define DRIZZLED_FUNCTIONS_DECIMAL_TYPECAST_H
+
+#include <drizzled/functions/func.h> 
+
+class Item_decimal_typecast :public Item_func
+{
+  my_decimal decimal_value;
+public:
+  Item_decimal_typecast(Item *a, int len, int dec) :Item_func(a)
+  {
+    decimals= dec;
+    max_length= my_decimal_precision_to_length(len, dec, unsigned_flag);
+  } 
+  String *val_str(String *str);
+  double val_real();
+  int64_t val_int();
+  my_decimal *val_decimal(my_decimal*);
+  enum Item_result result_type () const { return DECIMAL_RESULT; }
+  enum_field_types field_type() const { return DRIZZLE_TYPE_NEWDECIMAL; }
+  void fix_length_and_dec() {};
+  const char *func_name() const { return "decimal_typecast"; }
+  virtual void print(String *str, enum_query_type query_type);
+};
+
+
+#endif /* DRIZZLED_FUNCTIONS_DECIMAL_TYPECAST_H */

=== modified file 'drizzled/item_func.cc'
--- drizzled/item_func.cc	2008-10-09 20:33:45 +0000
+++ drizzled/item_func.cc	2008-10-09 21:04:57 +0000
@@ -151,99 +151,6 @@
 }
 
 
-String *Item_decimal_typecast::val_str(String *str)
-{
-  my_decimal tmp_buf, *tmp= val_decimal(&tmp_buf);
-  if (null_value)
-    return NULL;
-  my_decimal2string(E_DEC_FATAL_ERROR, tmp, 0, 0, 0, str);
-  return str;
-}
-
-
-double Item_decimal_typecast::val_real()
-{
-  my_decimal tmp_buf, *tmp= val_decimal(&tmp_buf);
-  double res;
-  if (null_value)
-    return 0.0;
-  my_decimal2double(E_DEC_FATAL_ERROR, tmp, &res);
-  return res;
-}
-
-
-int64_t Item_decimal_typecast::val_int()
-{
-  my_decimal tmp_buf, *tmp= val_decimal(&tmp_buf);
-  int64_t res;
-  if (null_value)
-    return 0;
-  my_decimal2int(E_DEC_FATAL_ERROR, tmp, unsigned_flag, &res);
-  return res;
-}
-
-
-my_decimal *Item_decimal_typecast::val_decimal(my_decimal *dec)
-{
-  my_decimal tmp_buf, *tmp= args[0]->val_decimal(&tmp_buf);
-  bool sign;
-  uint32_t precision;
-
-  if ((null_value= args[0]->null_value))
-    return NULL;
-  my_decimal_round(E_DEC_FATAL_ERROR, tmp, decimals, false, dec);
-  sign= dec->sign();
-  if (unsigned_flag)
-  {
-    if (sign)
-    {
-      my_decimal_set_zero(dec);
-      goto err;
-    }
-  }
-  precision= my_decimal_length_to_precision(max_length,
-                                            decimals, unsigned_flag);
-  if (precision - decimals < (uint) my_decimal_intg(dec))
-  {
-    max_my_decimal(dec, precision, decimals);
-    dec->sign(sign);
-    goto err;
-  }
-  return dec;
-
-err:
-  push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
-                      ER_WARN_DATA_OUT_OF_RANGE,
-                      ER(ER_WARN_DATA_OUT_OF_RANGE),
-                      name, 1);
-  return dec;
-}
-
-
-void Item_decimal_typecast::print(String *str, enum_query_type query_type)
-{
-  char len_buf[20*3 + 1];
-  char *end;
-
-  uint32_t precision= my_decimal_length_to_precision(max_length, decimals,
-                                                 unsigned_flag);
-  str->append(STRING_WITH_LEN("cast("));
-  args[0]->print(str, query_type);
-  str->append(STRING_WITH_LEN(" as decimal("));
-
-  end=int10_to_str(precision, len_buf,10);
-  str->append(len_buf, (uint32_t) (end - len_buf));
-
-  str->append(',');
-
-  end=int10_to_str(decimals, len_buf,10);
-  str->append(len_buf, (uint32_t) (end - len_buf));
-
-  str->append(')');
-  str->append(')');
-}
-
-
 double Item_func_plus::real_op()
 {
   double value= args[0]->val_real() + args[1]->val_real();

=== modified file 'drizzled/item_func.h'
--- drizzled/item_func.h	2008-10-09 20:33:45 +0000
+++ drizzled/item_func.h	2008-10-09 21:04:57 +0000
@@ -32,6 +32,7 @@
 
 #include <drizzled/functions/func.h>
 #include <drizzled/functions/connection_id.h>
+#include <drizzled/functions/decimal_typecast.h>
 #include <drizzled/functions/int.h>
 #include <drizzled/functions/numhybrid.h>
 #include <drizzled/functions/num_op.h>
@@ -40,27 +41,6 @@
 #include <drizzled/functions/signed.h>
 #include <drizzled/functions/unsigned.h>
 
-class Item_decimal_typecast :public Item_func
-{
-  my_decimal decimal_value;
-public:
-  Item_decimal_typecast(Item *a, int len, int dec) :Item_func(a)
-  {
-    decimals= dec;
-    max_length= my_decimal_precision_to_length(len, dec, unsigned_flag);
-  }
-  String *val_str(String *str);
-  double val_real();
-  int64_t val_int();
-  my_decimal *val_decimal(my_decimal*);
-  enum Item_result result_type () const { return DECIMAL_RESULT; }
-  enum_field_types field_type() const { return DRIZZLE_TYPE_NEWDECIMAL; }
-  void fix_length_and_dec() {};
-  const char *func_name() const { return "decimal_typecast"; }
-  virtual void print(String *str, enum_query_type query_type);
-};
-
-
 class Item_func_additive_op :public Item_num_op
 {
 public:

